summaryrefslogtreecommitdiffstats
path: root/kexi/core/kexiviewbase.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /kexi/core/kexiviewbase.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kexi/core/kexiviewbase.h')
-rw-r--r--kexi/core/kexiviewbase.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kexi/core/kexiviewbase.h b/kexi/core/kexiviewbase.h
index 60beadf8..139f0b2d 100644
--- a/kexi/core/kexiviewbase.h
+++ b/kexi/core/kexiviewbase.h
@@ -40,7 +40,7 @@ namespace KexiDB {
KexiViewBase has 'dirty' flag to indicate that view's data has changed.
This flag's state is reused by KexiDialogBase object that contain the view.
KexiViewBase objects can be also nested, using addChildView(): any actions and 'dirty' flag
- are transmited to tqparent view in this case.
+ are transmited to parent view in this case.
KexiViewBase objects are usually allocated within KexiDialogBase objects by implementing
KexiPart::createView() method. See query or table part code for examples.
@@ -55,13 +55,13 @@ class KEXICORE_EXPORT KexiViewBase : public TQWidget, public KexiActionProxy
TQ_OBJECT
public:
- KexiViewBase(KexiMainWindow *mainWin, TQWidget *tqparent, const char *name = 0);
+ KexiViewBase(KexiMainWindow *mainWin, TQWidget *parent, const char *name = 0);
virtual ~KexiViewBase();
//! \return kexi main window that contain this view
inline KexiMainWindow *mainWin() const { return m_mainWin; }
//! \return tqparent KexiDialogBase that contains this view, or 0 if no dialog contain this view
KexiDialogBase* parentDialog() const { return m_dialog; }
/*! Added for convenience.
@@ -112,9 +112,9 @@ class KEXICORE_EXPORT KexiViewBase : public TQWidget, public KexiActionProxy
virtual void propertySetSwitched();
/*! Sets dirty flag on or off. It the flag changes,
- dirty(bool) signal is emitted by tqparent dialog (KexiDialog),
- to inform the world about that. If this view has a tqparent view, setDirty()
- is called also on tqparent view.
+ dirty(bool) signal is emitted by parent dialog (KexiDialog),
+ to inform the world about that. If this view has a parent view, setDirty()
+ is called also on parent view.
Always use this function to update 'dirty' flag information. */
void setDirty(bool set);
@@ -233,13 +233,13 @@ class KEXICORE_EXPORT KexiViewBase : public TQWidget, public KexiActionProxy
virtual void setFocusInternal() { TQWidget::setFocus(); }
- /*! Allows to react on tqparent dialog's detaching (only for KMDI's ChildFrame mode)
+ /*! Allows to react on parent dialog's detaching (only for KMDI's ChildFrame mode)
- it is called by KexiDialogBase::youAreDetached().
Default implementation does nothing.
Implement it if you want to perform some appropriate actions. */
virtual void parentDialogDetached() {};
- /*! Allows to react on tqparent dialog's attaching (only for KMDI's ChildFrame mode)
+ /*! Allows to react on parent dialog's attaching (only for KMDI's ChildFrame mode)
- it is called by KexiDialogBase::youAreAttached().
Default implementation does nothing.
Implement it if you want to perform some appropriate actions. */
@@ -55,13 +55,13 @@ class KEXICORE_EXPORT KexiViewBase : public TQWidget, public KexiActionProxy
//! \return kexi main window that contain this view
inline KexiMainWindow *mainWin() const { return m_mainWin; }
- //! \return tqparent KexiDialogBase that contains this view, or 0 if no dialog contain this view
+ //! \return parent KexiDialogBase that contains this view, or 0 if no dialog contain this view
KexiDialogBase* parentDialog() const { return m_dialog; }
/*! Added for convenience.